declare const service: {
    name: string;
    slug: string;
    description: string;
    endpoints: ({
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    local_part: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            local_part: string;
            type?: undefined;
            config?: undefined;
            from?: undefined;
            to?: undefined;
            subject?: undefined;
            text?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                email: import("zod").ZodString;
                imap: import("zod").ZodObject<{
                    host: import("zod").ZodString;
                    port: import("zod").ZodNumber;
                    tls: import("zod").ZodString;
                    username: import("zod").ZodString;
                    password: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
                pop3: import("zod").ZodObject<{
                    host: import("zod").ZodString;
                    port: import("zod").ZodNumber;
                    tls: import("zod").ZodString;
                    username: import("zod").ZodString;
                    password: import("zod").ZodString;
                }, import("zod/v4/core").$strip>;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
        }[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    type: import("zod").ZodString;
                    config: import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodUnknown>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            type: string;
            config: {
                url: string;
                method: string;
            };
            local_part?: undefined;
            from?: undefined;
            to?: undefined;
            subject?: undefined;
            text?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: never[];
        requestBody: {
            description: string;
            fields: {
                schema: import("zod").ZodObject<{
                    from: import("zod").ZodString;
                    to: import("zod").ZodArray<import("zod").ZodString>;
                    subject: import("zod").ZodString;
                    text: import("zod").ZodOptional<import("zod").ZodString>;
                    html: import("zod").ZodOptional<import("zod").ZodString>;
                    attachments: import("zod").ZodOptional<import("zod").ZodArray<import("zod").ZodObject<{
                        filename: import("zod").ZodString;
                        content: import("zod").ZodString;
                        contentType: import("zod").ZodOptional<import("zod").ZodString>;
                    }, import("zod/v4/core").$strip>>>;
                    headers: import("zod").ZodOptional<import("zod").ZodRecord<import("zod").ZodString, import("zod").ZodString>>;
                }, import("zod/v4/core").$strip>;
            };
        };
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody: {
            from: string;
            to: string[];
            subject: string;
            text: string;
            local_part?: undefined;
            type?: undefined;
            config?: undefined;
        };
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: never[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
        responseFields?: undefined;
    } | {
        id: string;
        title: string;
        sectionTitle: string;
        method: string;
        path: string;
        description: string;
        pathParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        queryParams: {
            name: string;
            type: string;
            description: string;
            required: boolean;
        }[];
        requestBody: null;
        responseDescription: string;
        responseFields: {
            schema: import("zod").ZodObject<{
                activity: import("zod").ZodArray<import("zod").ZodObject<{
                    date: import("zod").ZodString;
                    inbound: import("zod").ZodNumber;
                    outbound: import("zod").ZodNumber;
                }, import("zod/v4/core").$strip>>;
                days: import("zod").ZodNumber;
            }, import("zod/v4/core").$strip>;
        };
        statuses: {
            code: number;
            description: string;
        }[];
        examplePath: string;
        exampleBody?: undefined;
    })[];
};
export default service;
//# sourceMappingURL=api-reference.d.ts.map