import { z } from 'zod';
/** Request payload for creating an email address */
export declare const CreateAddressRequestSchema: z.ZodObject<{
    local_part: z.ZodString;
}, z.core.$strip>;
/** Request payload for creating an email destination */
export declare const CreateEmailDestinationRequestSchema: z.ZodObject<{
    type: z.ZodString;
    config: z.ZodRecord<z.ZodString, z.ZodUnknown>;
}, z.core.$strip>;
export type CreateAddressRequest = z.infer<typeof CreateAddressRequestSchema>;
export type CreateEmailDestinationRequest = z.infer<typeof CreateEmailDestinationRequestSchema>;
//# sourceMappingURL=types.d.ts.map